@@ -86,9 +86,10 @@ import qualified Data.ByteString.Lazy.Char8 as L
 import qualified Data.CaseInsensitive       as CI
 import           Data.Function              (on)
 import           Data.List                  (foldl')
+import qualified Data.Map                   as Map
 import           Data.Maybe                 (isJust, isNothing)
 #if !MIN_VERSION_base(4,8,0)
-import           Data.Monoid                (Monoid(..))
+import           Data.Monoid                (Monoid (..))
 #endif
 import           Data.Monoid                (Last (Last, getLast))
 import qualified Data.Text                  as T
@@ -96,7 +97,7 @@ import qualified Data.Text.Encoding         as T
 #if MIN_VERSION_base(4,7,0)
 import           Data.Typeable              (Typeable)
 #else
-import           Data.Typeable              (TyCon, Typeable, Typeable1 (..), mkTyConApp, mkTyCon3)
+import           Data.Typeable              (TyCon, Typeable, Typeable1 (..), mkTyCon3, mkTyConApp)
 #endif
 import           Network                    (Socket)
 import           Numeric                    (readOct, showOct)
@@ -115,7 +116,7 @@ import           System.IO                  (hPutStrLn, stderr)
 import           Data.ByteString.Builder    (Builder, byteString, stringUtf8, toLazyByteString)
 import qualified System.IO.Streams          as Streams
 ------------------------------------------------------------------------------
-import           Snap.Core                  (MonadSnap, Request (rqClientAddr, rqClientPort), emptyResponse, finishWith, getRequest, logError, setContentLength, setContentType, setResponseBody, setResponseStatus)
+import           Snap.Core                  (MonadSnap, Request (rqClientAddr, rqClientPort, rqParams, rqPostParams), emptyResponse, finishWith, getsRequest, logError, setContentLength, setContentType, setResponseBody, setResponseStatus)
 import           Snap.Internal.Debug        (debug)
 
 
@@ -699,7 +700,7 @@ optDescrs defaults =
 defaultErrorHandler :: MonadSnap m => SomeException -> m ()
 defaultErrorHandler e = do
     debug "Snap.Http.Server.Config errorHandler:"
-    req <- getRequest
+    req <- getsRequest blindParams
     let sm = smsg req
     debug $ toString sm
     logError sm
@@ -711,6 +712,10 @@ defaultErrorHandler e = do
                $ emptyResponse
 
   where
+    blindParams r = r { rqPostParams = rmValues $ rqPostParams r
+                      , rqParams     = rmValues $ rqParams r }
+    rmValues = Map.map (const ["..."])
+
     errBody os = Streams.write (Just msgB) os >> return os
 
     toByteString = S.concat . L.toChunks . toLazyByteString
